diff gtk-gui/IBBoard.WarFoundry.GTK.FrmNewUnit.cs @ 6:cfc7683e73f9

Fix breakage from r33 by completing update of move to IBBoard.WarFoundry.GTK sub-packages no-open-ticket
author IBBoard <dev@ibboard.co.uk>
date Mon, 26 Jan 2009 20:16:07 +0000
parents 65279b85446f
children 58961ff391d4
line wrap: on
line diff
--- a/gtk-gui/IBBoard.WarFoundry.GTK.FrmNewUnit.cs	Sun Jan 25 14:52:18 2009 +0000
+++ b/gtk-gui/IBBoard.WarFoundry.GTK.FrmNewUnit.cs	Mon Jan 26 20:16:07 2009 +0000
@@ -1,14 +1,14 @@
 // ------------------------------------------------------------------------------
 //  <autogenerated>
 //      This code was generated by a tool.
-//      Mono Runtime Version: 2.0.50727.42
+//      Mono Runtime Version: 2.0.50727.1433
 // 
 //      Changes to this file may cause incorrect behavior and will be lost if 
 //      the code is regenerated.
 //  </autogenerated>
 // ------------------------------------------------------------------------------
 
-namespace IBBoard.WarFoundry {
+namespace IBBoard.WarFoundry.GTK {
     
     
     public partial class FrmNewUnit {
@@ -31,16 +31,16 @@
         
         protected virtual void Build() {
             Stetic.Gui.Initialize(this);
-            // Widget IBBoard.WarFoundry.FrmNewUnit
-            this.Name = "IBBoard.WarFoundry.FrmNewUnit";
-            this.Title = Mono.Unix.Catalog.GetString("Add new unit");
+            // Widget IBBoard.WarFoundry.GTK.FrmNewUnit
+            this.Name = "IBBoard.WarFoundry.GTK.FrmNewUnit";
+            this.Title = "Add new unit";
             this.Icon = Stetic.IconLoader.LoadIcon(this, "gtk-new", Gtk.IconSize.Menu, 16);
             this.WindowPosition = ((Gtk.WindowPosition)(4));
             this.Modal = true;
             this.SkipPagerHint = true;
             this.SkipTaskbarHint = true;
             this.HasSeparator = false;
             // Internal child IBBoard.WarFoundry.FrmNewUnit.VBox
             Gtk.VBox w1 = this.VBox;
             w1.Name = "dialog1_VBox";
             w1.BorderWidth = ((uint)(2));
@@ -55,7 +55,7 @@
             // Container child hbox1.Gtk.Box+BoxChild
             this.label1 = new Gtk.Label();
             this.label1.Name = "label1";
-            this.label1.LabelProp = Mono.Unix.Catalog.GetString("Unit Type:");
+            this.label1.LabelProp = "Unit Type:";
             this.hbox1.Add(this.label1);
             Gtk.Box.BoxChild w2 = ((Gtk.Box.BoxChild)(this.hbox1[this.label1]));
             w2.Position = 0;
@@ -95,7 +95,7 @@
             w7.Position = 0;
             w7.Expand = false;
             w7.Fill = false;
             // Internal child IBBoard.WarFoundry.FrmNewUnit.ActionArea
             Gtk.HButtonBox w8 = this.ActionArea;
             w8.Name = "dialog1_ActionArea";
             w8.Spacing = 6;
@@ -31,16 +31,16 @@
             this.SkipTaskbarHint = true;
             this.HasSeparator = false;
-            // Internal child IBBoard.WarFoundry.FrmNewUnit.VBox
+            // Internal child IBBoard.WarFoundry.GTK.FrmNewUnit.VBox
             Gtk.VBox w1 = this.VBox;
             w1.Name = "dialog1_VBox";
@@ -95,7 +95,7 @@
             w7.Expand = false;
             w7.Fill = false;
-            // Internal child IBBoard.WarFoundry.FrmNewUnit.ActionArea
+            // Internal child IBBoard.WarFoundry.GTK.FrmNewUnit.ActionArea
             Gtk.HButtonBox w8 = this.ActionArea;
             w8.Name = "dialog1_ActionArea";